---
title: auth
sidebarTitle: auth
---

# `fastmcp.server.auth.auth`

## Classes

### `OAuthProvider` <sup><a href="https://github.com/jlowin/fastmcp/blob/main/src/fastmcp/server/auth/auth.py#L14"><Icon icon="github" size="14" /></a></sup>
